package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.ElecPgSupplyHMapper;
import com.ruoyi.ems.domain.ElecPgSupplyH;
import com.ruoyi.ems.service.IElecPgSupplyHService;

/**
 * 电网供应计量-小时Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class EmsPgSupplyHServiceImpl implements IElecPgSupplyHService
{
    @Autowired
    private ElecPgSupplyHMapper emsPgSupplyHMapper;

    /**
     * 查询电网供应计量-小时
     * 
     * @param id 电网供应计量-小时主键
     * @return 电网供应计量-小时
     */
    @Override
    public ElecPgSupplyH selectPgSupplyHById(Long id)
    {
        return emsPgSupplyHMapper.selectPgSupplyHById(id);
    }

    /**
     * 查询电网供应计量-小时列表
     * 
     * @param admEmsPgSupplyH 电网供应计量-小时
     * @return 电网供应计量-小时
     */
    @Override
    public List<ElecPgSupplyH> selectPgSupplyHList(ElecPgSupplyH admEmsPgSupplyH)
    {
        return emsPgSupplyHMapper.selectPgSupplyHList(admEmsPgSupplyH);
    }

    /**
     * 新增电网供应计量-小时
     * 
     * @param admEmsPgSupplyH 电网供应计量-小时
     * @return 结果
     */
    @Override
    public int insertPgSupplyH(ElecPgSupplyH admEmsPgSupplyH)
    {
        return emsPgSupplyHMapper.insertPgSupplyH(admEmsPgSupplyH);
    }

    /**
     * 修改电网供应计量-小时
     * 
     * @param admEmsPgSupplyH 电网供应计量-小时
     * @return 结果
     */
    @Override
    public int updatePgSupplyH(ElecPgSupplyH admEmsPgSupplyH)
    {
        return emsPgSupplyHMapper.updatePgSupplyH(admEmsPgSupplyH);
    }

    /**
     * 批量删除电网供应计量-小时
     * 
     * @param ids 需要删除的电网供应计量-小时主键
     * @return 结果
     */
    @Override
    public int deletePgSupplyHByIds(Long[] ids)
    {
        return emsPgSupplyHMapper.deletePgSupplyHByIds(ids);
    }

    /**
     * 删除电网供应计量-小时信息
     * 
     * @param id 电网供应计量-小时主键
     * @return 结果
     */
    @Override
    public int deletePgSupplyHById(Long id)
    {
        return emsPgSupplyHMapper.deletePgSupplyHById(id);
    }
}
